| Safe Haskell | None |
|---|---|
| Language | Haskell98 |
HGamer3D.Data.Geometry2D
Description
Type definitions for 2D geometry
- data Point = Point {}
- rectFromPoints :: (Point, Point) -> ScreenRect
- pointsFromRect :: ScreenRect -> (Point, Point)
Documentation
A point has two coordinates an x and y one
rectFromPoints :: (Point, Point) -> ScreenRect Source #
derive a rectangle from upper left and lower right points
pointsFromRect :: ScreenRect -> (Point, Point) Source #
get upper left and lower right point from a rect